Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRequest ¶
func NewRequest(method, host string, opts ...RequestOption) (*http.Request, error)
NewRequest return valid http.Request struct from given arguments
func NewResponse ¶
func NewResponse(status int, opts ...ResponseOption) (*http.Response, error)
NewResponse return valid http.Response struct from given arguments
Types ¶
type HeaderRange ¶
HeaderRange defines an interface implement Range function for iterating over header values and populating them into a target
type RequestOption ¶
func WithRequestHeader ¶
func WithRequestHeader(headers map[string][]string) RequestOption
func WithRequestHeaderRangeSetter ¶
func WithRequestHeaderRangeSetter(hr HeaderRange) RequestOption
func WithRequestURI ¶
func WithRequestURI(rawURI string) RequestOption
type ResponseOption ¶
func WithResponseHeaderRangeSetter ¶
func WithResponseHeaderRangeSetter(hr HeaderRange) ResponseOption
Click to show internal directories.
Click to hide internal directories.